PoolGuard

Struct PoolGuard 

pub struct PoolGuard<'a, T: Send, F: Fn() -> T, const MAX_POOL_STACKS: usize>(/* private fields */);
A guard that is returned when a caller requests a value from the pool.

The purpose of the guard is to use RAII to automatically put the value back in the pool once it’s dropped.

Implementations

Source

impl<'a, T: Send, F: Fn() -> T, const MAX_POOL_STACKS: usize> PoolGuard<'a, T, F, MAX_POOL_STACKS>

pub fn put(this: PoolGuard<'_, T, F, MAX_POOL_STACKS>)

Consumes this guard and puts it back into the pool.

This circumvents the guard’s Drop implementation. This can be useful in circumstances where the automatic Drop results in poorer codegen, such as calling non-inlined functions.